@@ -5,7 +5,9 @@ __all__ = (
     "MetricsCreator",
     "MinMetricInfoCache",
     "MinMetricInfo",
+    "WriteRequest",
 )
 
 from .commands import MinMetricInfo, MinMetricInfoCache
 from .hosts import CommandFollower, CommandRequest, Host, MetricsCreator
+from .values import WriteRequest
